# Cuttle CLI

![alt text](/images/cuttle-logo.png)

## For Contributors


#### Building locally

```
python setup.py sdist bdist_wheel
```

#### Install using source

```
python setup.py install
```

#### Check contents of package

```
tar tzf dist/cuttle-<version>.tar.gz
```